#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# === This file is part of Calamares - <https://github.com/calamares> ===
#
#   Copyright 2015, Teo Mrnjavac <teo@kde.org>
#   Copyright 2017. Alf Gaida <agaida@siduction.org>
#
#   Calamares is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.
#
#   Calamares is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with Calamares. If not, see <http://www.gnu.org/licenses/>.

import subprocess
import libcalamares
import os


def check_dm():
    """
    return the real dm
    """
    root_mount_point = libcalamares.globalstorage.value("rootMountPoint")

    displaymanagers=["lightdm","sddm"]

    targetdm=[]

    dm_names= displaymanagers[:]


    for dm in dm_names:
        bin_path = "{!s}/usr/bin/{!s}".format(root_mount_point, dm)
        sbin_path = "{!s}/usr/sbin/{!s}".format(root_mount_point, dm)
        if os.path.exists(bin_path) or os.path.exists(sbin_path):
            targetdm.append(dm)
    return targetdm

def run():
    """
    Remove live user from target system
    """
    username = libcalamares.job.configuration["username"]

    targetdm=check_dm()

    for dm in targetdm:
        if dm == "sddm":
            libcalamares.utils.check_target_env_call(["sed","-i",
                "s/^User=/#User=/",
                "/etc/sddm.conf"
                ])
        elif dm == "lightdm":
            libcalamares.utils.check_target_env_call(["sed", "-i",
                "s/^autologin-session=/#autologin-session=/",
                "/etc/lightdm/lightdm.conf"])

    libcalamares.utils.check_target_env_call(["rm", "-rf",
                                              "/etc/sudoers.d/loongson"])
    try:
        libcalamares.utils.check_target_env_call(["userdel", "-f",
                                                  "-r", username])
    except subprocess.CalledProcessError as e:
        libcalamares.utils.debug("Cannot remove user. "
                                 "'userdel' terminated with exit code "
                                 "{}.".format(e.returncode))
    return None
